import { ApplicationDataSource } from '../database/datasource.js';
import { LtiResourceModel } from '../database/model.js';
import { LTIResourceStudent } from './lti_resource_student.js';
export class LTIResource {
    resource_model;
    resource_id;
    experiment_template_uri;
    students_synced = false;
    // #region Initializers
    constructor(resource_model) {
        this.resource_model = resource_model;
        this.resource_id = resource_model.id;
        this.experiment_template_uri = resource_model.experiment_template_uri;
    }
    static async getOrCreate(message, platform) {
        const resource_init = {
            platform: { id: platform.platform_model.id },
            resource_link_id: message.resource_link_id,
        };
        await ApplicationDataSource.createQueryBuilder(LtiResourceModel, 'resource').insert().values({ ...resource_init }).orIgnore().execute();
        const resource = await ApplicationDataSource.manager.findOneByOrFail(LtiResourceModel, resource_init);
        return new LTIResource(resource);
    }
    static async byId({ resource_id }) {
        const resource = await ApplicationDataSource.manager.findOneByOrFail(LtiResourceModel, { id: resource_id });
        return new LTIResource(resource);
    }
    static async list() {
        const resources = await ApplicationDataSource.manager.find(LtiResourceModel, {});
        return resources.map(resource => new LTIResource(resource));
    }
    // #endregion
    setNameService(context_memberships_url) {
        this.resource_model.namesServiceUrl = context_memberships_url;
        ApplicationDataSource.manager.save(LtiResourceModel, this.resource_model);
    }
    async syncStudents(force = false) {
        if (this.students_synced && !force)
            return;
        await LTIResourceStudent.updateStudentsFromLtiResource(this.resource_id);
        this.students_synced = true;
    }
    async getStudent(id) {
        await this.syncStudents();
        return LTIResourceStudent.byId({ resource_id: this.resource_id, ...id });
    }
    async getStudents() {
        await this.syncStudents();
        return LTIResourceStudent.list({ resource_id: this.resource_id });
    }
    async update(data) {
        if (data.experiment_template_uri)
            this.resource_model.experiment_template_uri = data.experiment_template_uri;
        await ApplicationDataSource.manager.save(LtiResourceModel, this.resource_model);
    }
    async delete() {
        await ApplicationDataSource.manager.delete(LtiResourceModel, this.resource_model);
    }
}
//# sourceMappingURL=lti_resource.js.map