import * as basicValidation from "./basicValidation.cjs";
/**
 * This function validates the inputs of a GET request on /lti/platform
 */
export function validateGetLtiPlatformInput() {
    return true;
}
/**
 * This function validates the outputs to a GET request on /lti/platform
 */
export function validateGetLtiPlatformOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!basicValidation.validateGetLtiPlatformResponse200Response(response.body)) {
            validateGetLtiPlatformOutput.errors = basicValidation.validateGetLtiPlatformResponse200Response.errors;
            return false;
        }
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    validateGetLtiPlatformOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a POST request on /lti/platform
 */
export function validatePostLtiPlatformInput() {
    return true;
}
/**
 * This function validates the outputs to a POST request on /lti/platform
 */
export function validatePostLtiPlatformOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 201) {
        if (response.headers) {
            if (!basicValidation.validatePostLtiPlatformHeaderLocationResponse(response.headers["Location"])
                && response.headers['Location'] !== undefined) {
                validatePostLtiPlatformOutput.errors = basicValidation.validatePostLtiPlatformHeaderLocationResponse.errors;
                return false;
            }
        }
        else {
            if (response.headers !== undefined) {
                return false;
            }
        }
        if (!basicValidation.validatePostLtiPlatformResponse201Response(response.body)) {
            validatePostLtiPlatformOutput.errors = basicValidation.validatePostLtiPlatformResponse201Response.errors;
            return false;
        }
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    validatePostLtiPlatformOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a GET request on /lti/platform/{platform_id}
 */
export function validateGetLtiPlatformByPlatformIdInput(parameters) {
    if (parameters) {
        if (!basicValidation.validatePlatformIdRequest(parameters["platform_id"])) {
            validateGetLtiPlatformByPlatformIdInput.errors = basicValidation.validatePlatformIdRequest.errors;
            return false;
        }
    }
    else {
        return false;
    }
    return true;
}
/**
 * This function validates the outputs to a GET request on /lti/platform/{platform_id}
 */
export function validateGetLtiPlatformByPlatformIdOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!basicValidation.validateGetLtiPlatformByPlatformIdResponse200Response(response.body)) {
            validateGetLtiPlatformByPlatformIdOutput.errors = basicValidation.validateGetLtiPlatformByPlatformIdResponse200Response.errors;
            return false;
        }
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    validateGetLtiPlatformByPlatformIdOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a PATCH request on /lti/platform/{platform_id}
 */
export function validatePatchLtiPlatformByPlatformIdInput(parameters) {
    if (parameters) {
        if (!basicValidation.validatePlatformIdRequest(parameters["platform_id"])) {
            validatePatchLtiPlatformByPlatformIdInput.errors = basicValidation.validatePlatformIdRequest.errors;
            return false;
        }
    }
    else {
        return false;
    }
    return true;
}
/**
 * This function validates the outputs to a PATCH request on /lti/platform/{platform_id}
 */
export function validatePatchLtiPlatformByPlatformIdOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!basicValidation.validatePatchLtiPlatformByPlatformIdResponse200Response(response.body)) {
            validatePatchLtiPlatformByPlatformIdOutput.errors = basicValidation.validatePatchLtiPlatformByPlatformIdResponse200Response.errors;
            return false;
        }
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    validatePatchLtiPlatformByPlatformIdOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a DELETE request on /lti/platform/{platform_id}
 */
export function validateDeleteLtiPlatformByPlatformIdInput(parameters) {
    if (parameters) {
        if (!basicValidation.validatePlatformIdRequest(parameters["platform_id"])) {
            validateDeleteLtiPlatformByPlatformIdInput.errors = basicValidation.validatePlatformIdRequest.errors;
            return false;
        }
    }
    else {
        return false;
    }
    return true;
}
/**
 * This function validates the outputs to a DELETE request on /lti/platform/{platform_id}
 */
export function validateDeleteLtiPlatformByPlatformIdOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 204) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    validateDeleteLtiPlatformByPlatformIdOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a POST request on /lti/platform/{platform_id}/login
 */
export function validatePostLtiPlatformByPlatformIdLoginInput(parameters, body) {
    if (parameters) {
        if (!basicValidation.validatePlatformIdRequest(parameters["platform_id"])) {
            validatePostLtiPlatformByPlatformIdLoginInput.errors = basicValidation.validatePlatformIdRequest.errors;
            return false;
        }
    }
    else {
        return false;
    }
    if (!basicValidation.validatePostLtiPlatformByPlatformIdLoginRequestBodyRequest(body)) {
        validatePostLtiPlatformByPlatformIdLoginInput.errors = basicValidation.validatePostLtiPlatformByPlatformIdLoginRequestBodyRequest.errors;
        return false;
    }
    return true;
}
/**
 * This function validates the outputs to a POST request on /lti/platform/{platform_id}/login
 */
export function validatePostLtiPlatformByPlatformIdLoginOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!basicValidation.validatePostLtiPlatformByPlatformIdLoginResponse200Response(response.body)) {
            validatePostLtiPlatformByPlatformIdLoginOutput.errors = basicValidation.validatePostLtiPlatformByPlatformIdLoginResponse200Response.errors;
            return false;
        }
        return true;
    }
    validatePostLtiPlatformByPlatformIdLoginOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a POST request on /lti/platform/{platform_id}/launch
 */
export function validatePostLtiPlatformByPlatformIdLaunchInput(parameters, body) {
    if (parameters) {
        if (!basicValidation.validatePlatformIdRequest(parameters["platform_id"])) {
            validatePostLtiPlatformByPlatformIdLaunchInput.errors = basicValidation.validatePlatformIdRequest.errors;
            return false;
        }
    }
    else {
        return false;
    }
    if (!basicValidation.validatePostLtiPlatformByPlatformIdLaunchRequestBodyRequest(body)) {
        validatePostLtiPlatformByPlatformIdLaunchInput.errors = basicValidation.validatePostLtiPlatformByPlatformIdLaunchRequestBodyRequest.errors;
        return false;
    }
    return true;
}
/**
 * This function validates the outputs to a POST request on /lti/platform/{platform_id}/launch
 */
export function validatePostLtiPlatformByPlatformIdLaunchOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!basicValidation.validatePostLtiPlatformByPlatformIdLaunchResponse200Response(response.body)) {
            validatePostLtiPlatformByPlatformIdLaunchOutput.errors = basicValidation.validatePostLtiPlatformByPlatformIdLaunchResponse200Response.errors;
            return false;
        }
        return true;
    }
    validatePostLtiPlatformByPlatformIdLaunchOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a GET request on /lti/platform/{platform_id}/jwks
 */
export function validateGetLtiPlatformByPlatformIdJwksInput(parameters) {
    if (parameters) {
        if (!basicValidation.validatePlatformIdRequest(parameters["platform_id"])) {
            validateGetLtiPlatformByPlatformIdJwksInput.errors = basicValidation.validatePlatformIdRequest.errors;
            return false;
        }
    }
    else {
        return false;
    }
    return true;
}
/**
 * This function validates the outputs to a GET request on /lti/platform/{platform_id}/jwks
 */
export function validateGetLtiPlatformByPlatformIdJwksOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!basicValidation.validateGetLtiPlatformByPlatformIdJwksResponse200Response(response.body)) {
            validateGetLtiPlatformByPlatformIdJwksOutput.errors = basicValidation.validateGetLtiPlatformByPlatformIdJwksResponse200Response.errors;
            return false;
        }
        return true;
    }
    validateGetLtiPlatformByPlatformIdJwksOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a GET request on /lti/resource
 */
export function validateGetLtiResourceInput() {
    return true;
}
/**
 * This function validates the outputs to a GET request on /lti/resource
 */
export function validateGetLtiResourceOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!basicValidation.validateGetLtiResourceResponse200Response(response.body)) {
            validateGetLtiResourceOutput.errors = basicValidation.validateGetLtiResourceResponse200Response.errors;
            return false;
        }
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    validateGetLtiResourceOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a GET request on /lti/resource/{resource_id}
 */
export function validateGetLtiResourceByResourceIdInput(parameters) {
    if (parameters) {
        if (!basicValidation.validateResourceIdRequest(parameters["resource_id"])) {
            validateGetLtiResourceByResourceIdInput.errors = basicValidation.validateResourceIdRequest.errors;
            return false;
        }
    }
    else {
        return false;
    }
    return true;
}
/**
 * This function validates the outputs to a GET request on /lti/resource/{resource_id}
 */
export function validateGetLtiResourceByResourceIdOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!basicValidation.validateGetLtiResourceByResourceIdResponse200Response(response.body)) {
            validateGetLtiResourceByResourceIdOutput.errors = basicValidation.validateGetLtiResourceByResourceIdResponse200Response.errors;
            return false;
        }
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    validateGetLtiResourceByResourceIdOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a PATCH request on /lti/resource/{resource_id}
 */
export function validatePatchLtiResourceByResourceIdInput(parameters, body) {
    if (parameters) {
        if (!basicValidation.validateResourceIdRequest(parameters["resource_id"])) {
            validatePatchLtiResourceByResourceIdInput.errors = basicValidation.validateResourceIdRequest.errors;
            return false;
        }
    }
    else {
        return false;
    }
    if (!basicValidation.validatePatchLtiResourceByResourceIdRequestBodyRequest(body)) {
        validatePatchLtiResourceByResourceIdInput.errors = basicValidation.validatePatchLtiResourceByResourceIdRequestBodyRequest.errors;
        return false;
    }
    return true;
}
/**
 * This function validates the outputs to a PATCH request on /lti/resource/{resource_id}
 */
export function validatePatchLtiResourceByResourceIdOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!basicValidation.validatePatchLtiResourceByResourceIdResponse200Response(response.body)) {
            validatePatchLtiResourceByResourceIdOutput.errors = basicValidation.validatePatchLtiResourceByResourceIdResponse200Response.errors;
            return false;
        }
        return true;
    }
    if (response.status === 400) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    validatePatchLtiResourceByResourceIdOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a DELETE request on /lti/resource/{resource_id}
 */
export function validateDeleteLtiResourceByResourceIdInput(parameters) {
    if (parameters) {
        if (!basicValidation.validateResourceIdRequest(parameters["resource_id"])) {
            validateDeleteLtiResourceByResourceIdInput.errors = basicValidation.validateResourceIdRequest.errors;
            return false;
        }
    }
    else {
        return false;
    }
    return true;
}
/**
 * This function validates the outputs to a DELETE request on /lti/resource/{resource_id}
 */
export function validateDeleteLtiResourceByResourceIdOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 204) {
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    validateDeleteLtiResourceByResourceIdOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a GET request on /lti/resource/{resource_id}/students
 */
export function validateGetLtiResourceByResourceIdStudentsInput(parameters) {
    if (parameters) {
        if (!basicValidation.validateResourceIdRequest(parameters["resource_id"])) {
            validateGetLtiResourceByResourceIdStudentsInput.errors = basicValidation.validateResourceIdRequest.errors;
            return false;
        }
    }
    else {
        return false;
    }
    return true;
}
/**
 * This function validates the outputs to a GET request on /lti/resource/{resource_id}/students
 */
export function validateGetLtiResourceByResourceIdStudentsOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!basicValidation.validateGetLtiResourceByResourceIdStudentsResponse200Response(response.body)) {
            validateGetLtiResourceByResourceIdStudentsOutput.errors = basicValidation.validateGetLtiResourceByResourceIdStudentsResponse200Response.errors;
            return false;
        }
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    validateGetLtiResourceByResourceIdStudentsOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a PATCH request on /lti/resource/{resource_id}/students
 */
export function validatePatchLtiResourceByResourceIdStudentsInput(parameters, body) {
    if (parameters) {
        if (!basicValidation.validateResourceIdRequest(parameters["resource_id"])) {
            validatePatchLtiResourceByResourceIdStudentsInput.errors = basicValidation.validateResourceIdRequest.errors;
            return false;
        }
    }
    else {
        return false;
    }
    if (!basicValidation.validatePatchLtiResourceByResourceIdStudentsRequestBodyRequest(body)) {
        validatePatchLtiResourceByResourceIdStudentsInput.errors = basicValidation.validatePatchLtiResourceByResourceIdStudentsRequestBodyRequest.errors;
        return false;
    }
    return true;
}
/**
 * This function validates the outputs to a PATCH request on /lti/resource/{resource_id}/students
 */
export function validatePatchLtiResourceByResourceIdStudentsOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!basicValidation.validatePatchLtiResourceByResourceIdStudentsResponse200Response(response.body)) {
            validatePatchLtiResourceByResourceIdStudentsOutput.errors = basicValidation.validatePatchLtiResourceByResourceIdStudentsResponse200Response.errors;
            return false;
        }
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    validatePatchLtiResourceByResourceIdStudentsOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a GET request on /lti/resource/{resource_id}/students/{student_id}
 */
export function validateGetLtiResourceByResourceIdStudentsByStudentIdInput(parameters) {
    if (parameters) {
        if (!basicValidation.validateResourceIdRequest(parameters["resource_id"])) {
            validateGetLtiResourceByResourceIdStudentsByStudentIdInput.errors = basicValidation.validateResourceIdRequest.errors;
            return false;
        }
        if (!basicValidation.validateStudentIdRequest(parameters["student_id"])) {
            validateGetLtiResourceByResourceIdStudentsByStudentIdInput.errors = basicValidation.validateStudentIdRequest.errors;
            return false;
        }
    }
    else {
        return false;
    }
    return true;
}
/**
 * This function validates the outputs to a GET request on /lti/resource/{resource_id}/students/{student_id}
 */
export function validateGetLtiResourceByResourceIdStudentsByStudentIdOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!basicValidation.validateGetLtiResourceByResourceIdStudentsByStudentIdResponse200Response(response.body)) {
            validateGetLtiResourceByResourceIdStudentsByStudentIdOutput.errors = basicValidation.validateGetLtiResourceByResourceIdStudentsByStudentIdResponse200Response.errors;
            return false;
        }
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    validateGetLtiResourceByResourceIdStudentsByStudentIdOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a PATCH request on /lti/resource/{resource_id}/students/{student_id}
 */
export function validatePatchLtiResourceByResourceIdStudentsByStudentIdInput(parameters, body) {
    if (parameters) {
        if (!basicValidation.validateResourceIdRequest(parameters["resource_id"])) {
            validatePatchLtiResourceByResourceIdStudentsByStudentIdInput.errors = basicValidation.validateResourceIdRequest.errors;
            return false;
        }
        if (!basicValidation.validateStudentIdRequest(parameters["student_id"])) {
            validatePatchLtiResourceByResourceIdStudentsByStudentIdInput.errors = basicValidation.validateStudentIdRequest.errors;
            return false;
        }
    }
    else {
        return false;
    }
    if (!basicValidation.validatePatchLtiResourceByResourceIdStudentsByStudentIdRequestBodyRequest(body)) {
        validatePatchLtiResourceByResourceIdStudentsByStudentIdInput.errors = basicValidation.validatePatchLtiResourceByResourceIdStudentsByStudentIdRequestBodyRequest.errors;
        return false;
    }
    return true;
}
/**
 * This function validates the outputs to a PATCH request on /lti/resource/{resource_id}/students/{student_id}
 */
export function validatePatchLtiResourceByResourceIdStudentsByStudentIdOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 200) {
        if (!basicValidation.validatePatchLtiResourceByResourceIdStudentsByStudentIdResponse200Response(response.body)) {
            validatePatchLtiResourceByResourceIdStudentsByStudentIdOutput.errors = basicValidation.validatePatchLtiResourceByResourceIdStudentsByStudentIdResponse200Response.errors;
            return false;
        }
        return true;
    }
    if (response.status === 401) {
        return true;
    }
    validatePatchLtiResourceByResourceIdStudentsByStudentIdOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
/**
 * This function validates the inputs of a PATCH request on /lti/session/{session_id}/experiment
 */
export function validatePatchLtiSessionBySessionIdExperimentInput(parameters, body) {
    if (parameters) {
        if (!basicValidation.validateSessionIdRequest(parameters["session_id"])) {
            validatePatchLtiSessionBySessionIdExperimentInput.errors = basicValidation.validateSessionIdRequest.errors;
            return false;
        }
    }
    else {
        return false;
    }
    if (!basicValidation.validatePatchLtiSessionBySessionIdExperimentRequestBodyRequest(body)) {
        validatePatchLtiSessionBySessionIdExperimentInput.errors = basicValidation.validatePatchLtiSessionBySessionIdExperimentRequestBodyRequest.errors;
        return false;
    }
    return true;
}
/**
 * This function validates the outputs to a PATCH request on /lti/session/{session_id}/experiment
 */
export function validatePatchLtiSessionBySessionIdExperimentOutput(response) {
    if (response.status < 100 || response.status >= 600)
        return false;
    if (response.status === 201) {
        return true;
    }
    validatePatchLtiSessionBySessionIdExperimentOutput.errors = `Response status ${response.status} is unexpected`;
    return false;
}
//# sourceMappingURL=requestValidation.js.map