import { platformFetch } from './message.js';
export function hasNameServiceClaims(obj) {
    return (!!obj &&
        obj['https://purl.imsglobal.org/spec/lti-nrps/claim/namesroleservice'] !== undefined &&
        obj['https://purl.imsglobal.org/spec/lti-nrps/claim/namesroleservice'].context_memberships_url !== undefined &&
        typeof obj['https://purl.imsglobal.org/spec/lti-nrps/claim/namesroleservice'].context_memberships_url === 'string' &&
        obj['https://purl.imsglobal.org/spec/lti-nrps/claim/namesroleservice'].service_versions !== undefined &&
        Array.isArray(obj['https://purl.imsglobal.org/spec/lti-nrps/claim/namesroleservice'].service_versions));
}
function isResourceMember(obj) {
    return (!!obj &&
        obj.user_id !== undefined &&
        typeof obj.user_id === 'string' &&
        (obj.name === undefined ||
            typeof obj.name === 'string') &&
        (obj.given_name === undefined ||
            typeof obj.given_name === 'string') &&
        (obj.family_name === undefined ||
            typeof obj.family_name === 'string'));
}
function isResourceMemberResponse(obj) {
    return (!!obj &&
        obj.members !== undefined &&
        Array.isArray(obj.members) &&
        obj.members.every(isResourceMember));
}
export async function membership(platform, namesServiceUrl) {
    const res = await platformFetch(namesServiceUrl, {
        headers: { Accept: 'application/vnd.ims.lti-nrps.v2.membershipcontainer+json' },
        platform,
        scopes: ['https://purl.imsglobal.org/spec/lti-nrps/scope/contextmembership.readonly'],
    });
    const raw = await res.json();
    if (!isResourceMemberResponse(raw)) {
        throw new Error('Invalid response');
    }
    return raw.members;
}
//# sourceMappingURL=membership.js.map