import { config } from '../config.js';
const base = `${config.BASE_URL}/lti`;
function parse(template, uri) {
    const match = uri.match(template);
    if (!match) {
        throw new Error('Invalid resource uri');
    }
    return match;
}
export const generate_platform = (id) => {
    return base + `/platform/${id.platform_id}`;
};
export const parse_platform = (uri) => {
    const match = parse(`${base}/platform/(.*)`, uri);
    return { platform_id: match[1] };
};
export const generate_platform_jwks = (id) => { return generate_platform(id) + '/jwks'; };
export const generate_platform_login = (id) => { return generate_platform(id) + '/login'; };
export const generate_platform_launch = (id) => { return generate_platform(id) + '/launch'; };
export const generate_resource = (id) => {
    return base + `/resource/${id.resource_id}`;
};
export const parse_resource = (uri) => {
    const match = parse(`${base}/resource/(.*)`, uri);
    return { resource_id: match[1] };
};
export const generate_resource_students = (id) => {
    return base + `/resource/${id.resource_id}/students`;
};
export const parse_resource_students = (uri) => {
    const match = parse(`${base}/resource/(.*)/students`, uri);
    return { resource_id: match[1] };
};
export const generate_resource_student = (id) => base + `/resource/${id.resource_id}/student/${id.student_id}`;
export const parse_resource_student = (uri) => {
    const match = parse(`${base}/resource/(.*)/student/(.*)`, uri);
    return { resource_id: match[1], student_id: match[2] };
};
export const generate_session = (id) => base + `/session/${id.session_id}`;
export const parse_session = (uri) => {
    const match = parse(`${base}/session/(.*)`, uri);
    return { session_id: match[1] };
};
export const generate_session_change_experiment = (id) => base + `/session/${id.session_id}/experiment`;
export const parse_session_change_experiment = (uri) => {
    const match = parse(`${base}/session/(.*)/experiment`, uri);
    return { session_id: match[1] };
};
//# sourceMappingURL=uris.js.map